IVGCVSW-8054 Update BuildTool to use TF2.14

* Update TF to 2.14
* Update Flatbuffers to 23.5.26
* BuildTool now clones ArmNN main branch instead of latest release

Signed-off-by: Ciara Sookarry <ciara.sookarry@arm.com>
Change-Id: I9c4e19655dce14ee817fb670f4ee9b5174eb4dcc
diff --git a/build-tool/scripts/common.sh b/build-tool/scripts/common.sh
index 421dc3d..0622d7e 100755
--- a/build-tool/scripts/common.sh
+++ b/build-tool/scripts/common.sh
@@ -50,14 +50,14 @@
                            CXX="$ANDROID64_x86_TOOLCHAIN"/bin/aarch64-linux-android"$ANDROID_API_VERSION"-clang++ "
 
 # Flatbuffers
-FLATBUFFERS_VERSION=2.0.6
+FLATBUFFERS_VERSION=23.5.26
 FLATBUFFERS_SRC="$SOURCE_DIR"/flatbuffers-"$FLATBUFFERS_VERSION"
 FLATBUFFERS_BUILD_ROOT="$BUILD_DIR"/flatbuffers
 FLATBUFFERS_BUILD_TARGET="$FLATBUFFERS_BUILD_ROOT"/"$TARGET_ARCH"_build
 FLATBUFFERS_BUILD_HOST="$FLATBUFFERS_BUILD_ROOT"/"$HOST_ARCH"_build # Location of flatc compiler
 
 # Tensorflow
-TENSORFLOW_VERSION="6f692f73cb2043b4a0b0446539cd8c15b3dd9220" #2.12 RC1 + PR #60015 to fix Cmake build.
+TENSORFLOW_VERSION=v2.14.0-rc1 # r2.14
 TENSORFLOW_SRC="$SOURCE_DIR"/tensorflow
 TFLITE_SRC="$TENSORFLOW_SRC"/tensorflow/lite
 SCHEMA_SRC="$TFLITE_SRC"/schema/schema.fbs
diff --git a/build-tool/scripts/build-armnn.sh b/build-tool/scripts/build-armnn.sh
index 147aedf..0075bba 100755
--- a/build-tool/scripts/build-armnn.sh
+++ b/build-tool/scripts/build-armnn.sh
@@ -190,8 +190,8 @@
 
   rm -rf "$ARMNN_SRC"
 
-  # Latest release branch of Arm NN is checked out by default
-  git clone https://github.com/ARM-software/armnn.git armnn
+  # Main branch of Arm NN is checked out
+  git clone --branch main https://github.com/ARM-software/armnn.git armnn
 
   cd "$ARMNN_SRC"
   local armnn_branch="$(git rev-parse --abbrev-ref HEAD)"